Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3206)

Unified Diff: chrome/common/pref_names.cc

Issue 357723003: Implement prediction_options. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Nit. Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« chrome/browser/profiles/profile_io_data.cc ('K') | « chrome/common/pref_names.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/pref_names.cc
diff --git a/chrome/common/pref_names.cc b/chrome/common/pref_names.cc
index ef8cfde3c51496cc0baddadf1b74d49df1856758..859b7094a092f986d97304cd952243dee3168d9b 100644
--- a/chrome/common/pref_names.cc
+++ b/chrome/common/pref_names.cc
@@ -411,8 +411,8 @@ const char kMultipleProfilePrefMigration[] =
// of web pages, and resource prefetching.
// NOTE: The "dns_prefetching.enabled" value is used so that historical user
// preferences are not lost.
// TODO(bnc): Remove kNetworkPredictionEnabled once kAllowNetworkPrediction is
// functioning as per crbug.com/334602.
const char kNetworkPredictionEnabled[] = "dns_prefetching.enabled";
// A preference of enum chrome_browser_net::NetworkPredictionOptions shows
@@ -420,7 +420,7 @@ const char kNetworkPredictionEnabled[] = "dns_prefetching.enabled";
// Actions include DNS prefetching, TCP and SSL preconnection, prerendering
// of web pages, and resource prefetching.
// TODO(bnc): Implement this preference as per crbug.com/334602.
-const char kAllowNetworkPrediction[] = "net.allow_network_prediction";
+const char kNetworkPredictionOptions[] = "net.network_prediction_options";
// An integer representing the state of the default apps installation process.
// This value is persisted in the profile's user preferences because the process
« chrome/browser/profiles/profile_io_data.cc ('K') | « chrome/common/pref_names.h ('k') | no next file » | no next file with comments »
@@ -411,8 +411,8 @@ const char kMultipleProfilePrefMigration[] =
// NOTE: The "dns_prefetching.enabled" value is used so that historical user
// preferences are not lost.
-// TODO(bnc): Remove kNetworkPredictionEnabled once kAllowNetworkPrediction is
-// functioning as per crbug.com/334602.
+// TODO(bnc): Remove kNetworkPredictionEnabled once kNetworkPredictionOptions
+// is functioning as per crbug.com/334602.
const char kNetworkPredictionEnabled[] = "dns_prefetching.enabled";
// A preference of enum chrome_browser_net::NetworkPredictionOptions shows

Powered by Google App Engine
This is Rietveld 408576698